@@ -1,15 +1,15 @@
 import os
 import threading
 from tempfile import NamedTemporaryFile
-from typing import Generator, List, Optional, Union
+from typing import Any, Generator, List, Optional, Union
 
-import deltachat as dc  # type: ignore
+import deltachat as dc
 import py
 from deltachat import Account, Chat, Contact, Message, account_hookimpl
 from deltachat.capi import lib
 from deltachat.cutil import from_dc_charpointer
-from deltachat.message import parse_system_add_remove  # type: ignore
-from deltachat.tracker import ConfigureTracker  # type: ignore
+from deltachat.message import parse_system_add_remove
+from deltachat.tracker import ConfigureTracker
 
 from .builtin.admin import add_admin, del_admin, get_admins
 from .builtin.cmdline import PluginCmd
@@ -76,9 +76,7 @@ class Replies:
         l = []
         for msg in self._send_replies_to_core():
             self.logger.debug(
-                "reply id={} chat={} sent with text: {!r}".format(
-                    msg.id, msg.chat, msg.text[:50]
-                )
+                f"reply id={msg.id} chat={msg.chat} sent with text: {msg.text[:50]!r}"
             )
             l.append(msg)
         return l
@@ -357,25 +355,25 @@ class DeltaBot:
         """Return True if this bot account is successfully configured."""
         return bool(self.account.is_configured())
 
-    def perform_configure_address(self, email: str, password: str) -> bool:
+    def perform_configure_address(self, email: str, password: str, **kwargs) -> bool:
         """perform initial email/password bot account configuration."""
         assert not self.is_configured() or self.account.get_config("addr") == email
 
-        self.account.update_config(
-            dict(
-                addr=email,
-                mail_pw=password,
-                bot=1,
-                # set some useful bot defaults on the account
-                delete_server_after=1,
-                delete_device_after=2592000,
-                e2ee_enabled=1,
-                sentbox_watch=0,
-                mvbox_move=0,
-                bcc_self=0,
-                selfstatus="I'm a Delta Chat bot 🤖. Send me /help for more info.\n\nSource code: https://github.com/simplebot-org/simplebot",
-            )
+        configs = dict(
+            addr=email,
+            mail_pw=password,
+            bot=1,
+            # set some useful bot defaults on the account
+            delete_server_after=1,
+            delete_device_after=2592000,
+            e2ee_enabled=1,
+            sentbox_watch=0,
+            mvbox_move=0,
+            bcc_self=0,
+            selfstatus="I'm a Delta Chat bot 🤖. Send me /help for more info.\n\nSource code: https://github.com/simplebot-org/simplebot",
+            **kwargs,
         )
+        self.account.update_config(configs)
 
         tracker = ConfigureTracker(self.account)
         with self.account.temp_plugin(tracker) as configtracker:
@@ -426,15 +424,18 @@ class DeltaBot:
             if not c.admin or is_admin:
                 if c.cmd != "/set" or has_prefs:
                     cmds.append(c)
+        cmds.sort(key=lambda c: c.cmd)
 
         filters = []
         for f in self.filters._filter_defs.values():
             if not f.admin or is_admin:
                 filters.append(f)
+        filters.sort(key=lambda f: f.name)
 
         plugins = []
-        for plug, dist in bot.plugins._pm.list_plugin_distinfo():
+        for plug, _ in bot.plugins._pm.list_plugin_distinfo():
             plugins.append(bot.plugins._pm.get_name(plug))
+        plugins.sort()
 
         html = help_template.render(
             addr=bot.self_contact.addr, cmds=cmds, filters=filters, plugins=plugins
@@ -548,6 +549,8 @@ class IncomingEventHandler:
         self._needs_check = threading.Event()
         self._needs_check.set()
         self._running = True
+        self._thread: threading.Thread
+        self.db: Any
 
     def start(self) -> None:
         self.logger.debug("starting bot-event-handler THREAD")
@@ -576,12 +579,7 @@ class IncomingEventHandler:
         # bot authors to having to deal with deaddrop/contact requests.
         message.create_chat()
         self.logger.debug(
-            "incoming message from {} id={} chat={} text={!r}".format(
-                message.get_sender_contact().addr,
-                message.id,
-                message.chat.id,
-                message.text[:50],
-            )
+            f"incoming message from {message.get_sender_contact().addr} id={message.id} chat={message.chat.id} text={message.text[:50]!r}"
         )
 
         self.db.put_msg(message.id)
